@@ -11,7 +11,7 @@ def getSolcatcherDbCalls(endpoint=None):
   return getEndpointUrl(endpoint=endpoint,url="https://solcatcher.io/dbCalls")
 def get_db_header(headers=None, api_key=None):
     # Start with existing or default headers
-    headers = headers or {"Content-Type": "application/json"}
+    header = {}
 
     # Retrieve the key from environment or config
     key = api_key or get_env_value('SOLCATCHER_DB_API_KEY')
@@ -20,10 +20,10 @@ def get_db_header(headers=None, api_key=None):
     print("DEBUG: SOLCATCHER_DB_API_KEY ->", str(get_env_value('SOLCATCHER_DB_API_KEY')))
     # If key is not None, add the header; otherwise skip it
     if key:
-        headers["X-API-KEY"] = str(key) if key else ""
+        header["X-API-KEY"] = str(key) if key else ""
     # else do not set "X-API-KEY" at all
-
-    return headers
+    header.update(headers or get_headers())
+    return header
 def post_request(endpoint, **kwargs):
     url = getSolcatcherDbCalls(endpoint=endpoint)
     response = requests.post(url=url, data=json.dumps(kwargs), headers=get_headers())
